@@ -1,5 +1,5 @@
 package WWW::LinkChecker::Internal::App::Command::check;
-$WWW::LinkChecker::Internal::App::Command::check::VERSION = '0.8.1';
+$WWW::LinkChecker::Internal::App::Command::check::VERSION = '0.8.2';
 use strict;
 use warnings;
 use 5.014;
@@ -54,9 +54,11 @@ sub execute
         stack            => [ { url => $start_url, from => undef(), } ],
         encountered_urls => { $start_url => 1, },
         };
+    my $stack            = $state->{stack};
+    my $encountered_urls = $state->{encountered_urls};
 STACK:
 
-    while ( my $url_rec = $state->{stack}->[-1] )
+    while ( my $url_rec = pop( @{$stack} ) )
     {
         my $url = $url_rec->{'url'};
         print "Checking SRC URL '$url'\n";
@@ -66,6 +68,7 @@ STACK:
 
         if ($@)
         {
+            push @{$stack}, $url_rec;
             if ($state_fn)
             {
                 path($state_fn)->spew_utf8( encode_json($state) );
@@ -73,7 +76,6 @@ STACK:
             my $from = ( $url_rec->{from} // "START" );
             die "SRC URL $from points to '$url'.";
         }
-        pop( @{ $state->{stack} } );
 
         if ( any { $url =~ $_ } @pre_skip_regexes )
         {
@@ -84,12 +86,12 @@ STACK:
         {
             my $dest_url = $link->url_abs() . "";
             $dest_url =~ s{#[^#]+\z}{}ms;
-            if (    ( !exists( $state->{encountered_urls}->{$dest_url} ) )
+            if (    ( !exists( $encountered_urls->{$dest_url} ) )
                 and $dest_url =~ m{\A\Q$base_url\E}ms
                 and ( none { $dest_url =~ $_ } @before_insert_skips_regexes ) )
             {
-                $state->{encountered_urls}->{$dest_url} = 1;
-                push @{ $state->{stack} }, { url => $dest_url, from => $url, };
+                $encountered_urls->{$dest_url} = 1;
+                push @{$stack}, { url => $dest_url, from => $url, };
             }
         }
     }
@@ -110,7 +112,7 @@ __END__
 
 =head1 VERSION
 
-version 0.8.1
+version 0.8.2
 
 =for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
